==> sentry-8.1.4.tar.gz: sentry-8.1.4/src/sentry/static/sentry/app/index.js <==
import jQuery from 'jquery';

// setup jquery for CSRF tokens
function getCookie(name) {
  let cookieValue = null;
  if (document.cookie && document.cookie !== '') {
    let cookies = document.cookie.split(';');
    for (let i = 0; i < cookies.length; i++) {
      let cookie = jQuery.trim(cookies[i]);
      // Does this cookie string begin with the name we want?
      if (cookie.substring(0, name.length + 1) == (name + '=')) {
        cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
        break;
      }
    }
  }
  return cookieValue;
}

let csrftoken = getCookie('csrf');

function csrfSafeMethod(method) {
  // these HTTP methods do not require CSRF protection
  return (/^(GET|HEAD|OPTIONS|TRACE)$/.test(method));
}
jQuery.ajaxSetup({
  beforeSend: function(xhr, settings) {
    if (!csrfSafeMethod(settings.type) && !this.crossDomain) {
      xhr.setRequestHeader('X-CSRFToken', csrftoken);
    }
  }
});

// these get exported to a global variable, which is important as its the only
// way we can call into scoped objects
export default {
  jQuery: jQuery,
  moment: require('moment'),
  Raven: require('raven-js'),
  React: require('react'),
  ReactDOM: require('react-dom'),
  Router: require('react-router'),

  Sentry: {
    api: require('./api'),
    routes: require('./routes'),
    createHistory: require('history/lib/createBrowserHistory'),
    Alerts: require('./components/alerts'),
    mixins: {
      ApiMixin: require('./mixins/apiMixin'),
    },
    BarChart: require('./components/barChart'),
    i18n: require('./locale'),
    ConfigStore: require('./stores/configStore'),
    DropdownLink: require('./components/dropdownLink'),
    FlotChart: require('./components/flotChart'),
    HookStore: require('./stores/hookStore'),
    Indicators: require('./components/indicators'),
    LoadingError: require('./components/loadingError'),
    LoadingIndicator: require('./components/loadingIndicator'),
    ListLink: require('./components/listLink'),
    MenuItem: require('./components/menuItem'),
    Pagination: require('./components/pagination'),
    ProjectSelector: require('./components/projectHeader/projectSelector'),
    RuleEditor: require('./views/ruleEditor'),
    TimeSince: require('./components/timeSince')
  }
};

==> sentry-8.9.0.tar.gz: sentry-8.9.0/src/sentry/static/sentry/app/index.js <==
import jQuery from 'jquery';

import plugins from './plugins';

const csrfCookieName = window.csrfCookieName || 'sc';

// setup jquery for CSRF tokens
function getCookie(name) {
  let cookieValue = null;
  if (document.cookie && document.cookie !== '') {
    let cookies = document.cookie.split(';');
    for (let i = 0; i < cookies.length; i++) {
      let cookie = jQuery.trim(cookies[i]);
      // Does this cookie string begin with the name we want?
      if (cookie.substring(0, name.length + 1) == (name + '=')) {
        cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
        break;
      }
    }
  }
  return cookieValue;
}

function csrfSafeMethod(method) {
  // these HTTP methods do not require CSRF protection
  return (/^(GET|HEAD|OPTIONS|TRACE)$/.test(method));
}

jQuery.ajaxSetup({
  beforeSend: function(xhr, settings) {
    if (!csrfSafeMethod(settings.type) && !this.crossDomain) {
      xhr.setRequestHeader('X-CSRFToken', getCookie(csrfCookieName));
    }
  }
});

// these get exported to a global variable, which is important as its the only
// way we can call into scoped objects

export default {
  jQuery: jQuery,
  moment: require('moment'),
  Raven: require('raven-js'),
  React: require('react'),
  ReactDOM: require('react-dom'),
  Reflux: require('reflux'),
  Router: require('react-router'),

  Sentry: {
    api: require('./api'),
    routes: require('./routes'),
    plugins: {
      add: plugins.add,
      BasePlugin: plugins.BasePlugin,
      DefaultIssuePlugin: plugins.DefaultIssuePlugin
    },

    createHistory: require('history/lib/createBrowserHistory'),
    Alerts: require('./components/alerts'),
    AlertActions: require('./actions/alertActions'),
    AvatarSettings: require('./components/avatarSettings'),
    mixins: {
      ApiMixin: require('./mixins/apiMixin'),
    },
    BarChart: require('./components/barChart'),
    i18n: require('./locale'),
    ConfigStore: require('./stores/configStore'),
    Count: require('./components/count'),
    DateTime: require('./components/dateTime'),
    DropdownLink: require('./components/dropdownLink'),
    FlotChart: require('./components/flotChart'),
    Form: require('./components/forms/form'),
    FormState: require('./components/forms/index').FormState,
    HookStore: require('./stores/hookStore'),
    Indicators: require('./components/indicators'),
    IndicatorStore: require('./stores/indicatorStore'),
    LoadingError: require('./components/loadingError'),
    LoadingIndicator: require('./components/loadingIndicator'),
    ListLink: require('./components/listLink'),
    MenuItem: require('./components/menuItem'),
    OrganizationHomeContainer: require('./components/organizations/homeContainer'),
    Pagination: require('./components/pagination'),
    PluginConfig: require('./components/pluginConfig'),
    ProjectIssueTracking: require('./views/projectIssueTracking'),
    ProjectSelector: require('./components/projectHeader/projectSelector'),
    RuleEditor: require('./views/ruleEditor'),
    StackedBarChart: require('./components/stackedBarChart'),
    TimeSince: require('./components/timeSince'),
    TodoList: require('./components/todos'),
    U2fEnrollment: require('./components/u2fenrollment'),
    U2fSign: require('./components/u2fsign'),
    utils: {
      errorHandler: require('./utils/errorHandler')
    }
  }
};
